@@ -65,7 +65,7 @@ public final class AccountingConstants {
 
         @Override
         public String toString() {
-            return name().toString().replaceAll("_", " ");
+            return name().replace("_", " ");
         }
 
         public Integer getValue() {
@@ -126,7 +126,7 @@ public final class AccountingConstants {
 
         @Override
         public String toString() {
-            return name().toString().replaceAll("_", " ");
+            return name().replace("_", " ");
         }
 
         public Integer getValue() {
@@ -202,7 +202,7 @@ public final class AccountingConstants {
 
         @Override
         public String toString() {
-            return name().replaceAll("_", " ");
+            return name().replace("_", " ");
         }
 
         public String getValue() {
@@ -249,7 +249,7 @@ public final class AccountingConstants {
 
         @Override
         public String toString() {
-            return name().replaceAll("_", " ");
+            return name().replace("_", " ");
         }
 
         public String getValue() {
@@ -281,7 +281,7 @@ public final class AccountingConstants {
 
         @Override
         public String toString() {
-            return name().replaceAll("_", " ");
+            return name().replace("_", " ");
         }
 
         public Integer getValue() {
@@ -330,7 +330,7 @@ public final class AccountingConstants {
 
         @Override
         public String toString() {
-            return name().replaceAll("_", " ");
+            return name().replace("_", " ");
         }
 
         public Integer getValue() {
@@ -386,7 +386,7 @@ public final class AccountingConstants {
 
         @Override
         public String toString() {
-            return name().replaceAll("_", " ");
+            return name().replace("_", " ");
         }
 
         public String getValue() {
@@ -424,7 +424,7 @@ public final class AccountingConstants {
 
         @Override
         public String toString() {
-            return name().replaceAll("_", " ");
+            return name().replace("_", " ");
         }
 
         public String getValue() {
@@ -464,7 +464,7 @@ public final class AccountingConstants {
 
         @Override
         public String toString() {
-            return name().replaceAll("_", " ");
+            return name().replace("_", " ");
         }
 
         public Integer getValue() {
@@ -529,7 +529,7 @@ public final class AccountingConstants {
 
         @Override
         public String toString() {
-            return name().replaceAll("_", " ");
+            return name().replace("_", " ");
         }
 
         public Integer getValue() {
@@ -568,7 +568,7 @@ public final class AccountingConstants {
 
         @Override
         public String toString() {
-            return name().replaceAll("_", " ");
+            return name().replace("_", " ");
         }
 
         public String getValue() {
