@@ -23,7 +23,7 @@ public enum DefaultCodeValue implements CodeValue {
     // Charge-off reason
     FRAUD("Fraud"), //
     DELINQUENT("Delinquent"), //
-    OTHER("Other"); //
+    OTHER("Other"), BAD_DEBT("Bad Debt"), FORGIVEN("Forgiven"), TEST("Test"); //
 
     private final String customName;
 
