@@ -28,10 +28,16 @@ import java.math.BigDecimal;
 import java.time.LocalDate;
 import java.time.format.DateTimeFormatter;
 import java.util.ArrayList;
+import java.util.HashMap;
 import java.util.List;
+import java.util.Locale;
+import java.util.Map;
 import java.util.Objects;
 import java.util.stream.Collectors;
 import lombok.extern.slf4j.Slf4j;
+import org.apache.fineract.client.feign.FineractFeignClient;
+import org.apache.fineract.client.feign.services.JournalEntriesApi;
+import org.apache.fineract.client.feign.services.LoansApi;
 import org.apache.fineract.client.models.GetJournalEntriesTransactionIdResponse;
 import org.apache.fineract.client.models.GetLoansLoanIdResponse;
 import org.apache.fineract.client.models.GetLoansLoanIdTransactions;
@@ -39,16 +45,12 @@ import org.apache.fineract.client.models.JournalEntryCommand;
 import org.apache.fineract.client.models.JournalEntryTransactionItem;
 import org.apache.fineract.client.models.PostJournalEntriesResponse;
 import org.apache.fineract.client.models.PostLoansResponse;
-import org.apache.fineract.client.services.JournalEntriesApi;
-import org.apache.fineract.client.services.LoansApi;
 import org.apache.fineract.test.data.TransactionType;
 import org.apache.fineract.test.factory.LoanRequestFactory;
-import org.apache.fineract.test.helper.ErrorHelper;
 import org.apache.fineract.test.helper.ErrorMessageHelper;
 import org.apache.fineract.test.stepdef.AbstractStepDef;
 import org.apache.fineract.test.support.TestContextKey;
 import org.springframework.beans.factory.annotation.Autowired;
-import retrofit2.Response;
 
 @Slf4j
 public class JournalEntriesStepDef extends AbstractStepDef {
@@ -56,27 +58,33 @@ public class JournalEntriesStepDef extends AbstractStepDef {
     public static final String DATE_FORMAT = "dd MMMM yyyy";
 
     @Autowired
-    private LoansApi loansApi;
-
-    @Autowired
-    private JournalEntriesApi journalEntriesApi;
+    private FineractFeignClient fineractFeignClient;
 
     @Autowired
     private LoanRequestFactory loanRequestFactory;
 
+    private LoansApi loansApi() {
+        return fineractFeignClient.loans();
+    }
+
+    private JournalEntriesApi journalEntriesApi() {
+        return fineractFeignClient.journalEntries();
+    }
+
     @Then("Loan Transactions tab has a {string} transaction with date {string} which has the following Journal entries:")
     public void journalEntryDataCheck(String transactionType, String transactionDate, DataTable table) throws IOException {
         DateTimeFormatter formatter = DateTimeFormatter.ofPattern(DATE_FORMAT);
-        Response<PostLoansResponse> loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
-        long loanId = loanResponse.body().getLoanId();
-
-        Response<GetLoansLoanIdResponse> loanDetailsResponse = loansApi.retrieveLoan(loanId, false, "transactions", "", "").execute();
-        ErrorHelper.checkSuccessfulApiCall(loanDetailsResponse);
+        PostLoansResponse loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
+        long loanId = loanResponse.getLoanId();
 
+        Map<String, Object> queryParams = new HashMap<>();
+        queryParams.put("staffInSelectedOfficeOnly", false);
+        queryParams.put("associations", "transactions");
+        GetLoansLoanIdResponse loanDetailsResponse = loansApi().retrieveLoan(loanId, queryParams);
         TransactionType transactionType1 = TransactionType.valueOf(transactionType);
         String transactionTypeExpected = transactionType1.getValue();
 
-        List<GetLoansLoanIdTransactions> transactions = loanDetailsResponse.body().getTransactions();
+        List<GetLoansLoanIdTransactions> transactions = loanDetailsResponse.getTransactions();
         List<GetLoansLoanIdTransactions> transactionsMatch = transactions.stream()
                 .filter(t -> transactionDate.equals(formatter.format(t.getDate()))
                         && transactionTypeExpected.equals(t.getType().getCode().substring(20)))
@@ -114,7 +122,8 @@ public class JournalEntriesStepDef extends AbstractStepDef {
                 }).collect(Collectors.toList());
                 possibleActualValuesList.add(actualValuesList);
 
-                boolean containsExpectedValues = actualValuesList.stream().anyMatch(actualValues -> actualValues.equals(expectedValues));
+                boolean containsExpectedValues = actualValuesList.stream()
+                        .anyMatch(actualValues -> matchesWithBigDecimalComparison(actualValues, expectedValues));
                 if (containsExpectedValues) {
                     containsAnyExpected = true;
                 }
@@ -125,38 +134,50 @@ public class JournalEntriesStepDef extends AbstractStepDef {
         }
     }
 
+    private boolean matchesWithBigDecimalComparison(List<String> actualValues, List<String> expectedValues) {
+        if (actualValues.size() != expectedValues.size()) {
+            return false;
+        }
+        for (int i = 0; i < actualValues.size(); i++) {
+            String actual = actualValues.get(i);
+            String expected = expectedValues.get(i);
+            if (!valuesMatch(actual, expected)) {
+                return false;
+            }
+        }
+        return true;
+    }
+
+    private boolean valuesMatch(String actual, String expected) {
+        if (Objects.equals(actual, expected)) {
+            return true;
+        }
+        if (actual == null || expected == null) {
+            return false;
+        }
+        try {
+            BigDecimal actualDecimal = new BigDecimal(actual);
+            BigDecimal expectedDecimal = new BigDecimal(expected);
+            return actualDecimal.compareTo(expectedDecimal) == 0;
+        } catch (NumberFormatException e) {
+            return actual.equals(expected);
+        }
+    }
+
     public List<List<JournalEntryTransactionItem>> getJournalLinesActualList(List<GetLoansLoanIdTransactions> transactionsMatch) {
         List<List<JournalEntryTransactionItem>> journalLinesActualList = transactionsMatch.stream().map(t -> {
             String transactionId = "L" + t.getId();
-            Response<GetJournalEntriesTransactionIdResponse> journalEntryDataResponse = null;
+            GetJournalEntriesTransactionIdResponse journalEntryDataResponse = null;
             try {
-                journalEntryDataResponse = journalEntriesApi.retrieveAll1(//
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        transactionId, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        true//
-                ).execute();
-                ErrorHelper.checkSuccessfulApiCall(journalEntryDataResponse);
-            } catch (IOException e) {
+                Map<String, Object> journalQueryParams = new HashMap<>();
+                journalQueryParams.put("transactionId", transactionId);
+                journalQueryParams.put("runningBalance", true);
+                journalEntryDataResponse = journalEntriesApi().retrieveAll1(journalQueryParams);
+            } catch (Exception e) {
                 log.error("Exception", e);
             }
 
-            return journalEntryDataResponse.body().getPageItems();
+            return journalEntryDataResponse.getPageItems();
         }).collect(Collectors.toList());
 
         return journalLinesActualList;
@@ -165,16 +186,17 @@ public class JournalEntriesStepDef extends AbstractStepDef {
     @Then("Loan Transactions tab has {int} a {string} transactions with date {string} which has the following Journal entries:")
     public void journalEntryDataCheck(int numberTrns, String transactionType, String transactionDate, DataTable table) throws IOException {
         DateTimeFormatter formatter = DateTimeFormatter.ofPattern(DATE_FORMAT);
-        Response<PostLoansResponse> loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
-        long loanId = loanResponse.body().getLoanId();
-
-        Response<GetLoansLoanIdResponse> loanDetailsResponse = loansApi.retrieveLoan(loanId, false, "transactions", "", "").execute();
-        ErrorHelper.checkSuccessfulApiCall(loanDetailsResponse);
+        PostLoansResponse loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
+        long loanId = loanResponse.getLoanId();
 
+        Map<String, Object> queryParams = new HashMap<>();
+        queryParams.put("staffInSelectedOfficeOnly", false);
+        queryParams.put("associations", "transactions");
+        GetLoansLoanIdResponse loanDetailsResponse = loansApi().retrieveLoan(loanId, queryParams);
         TransactionType transactionType1 = TransactionType.valueOf(transactionType);
         String transactionTypeExpected = transactionType1.getValue();
 
-        List<GetLoansLoanIdTransactions> transactions = loanDetailsResponse.body().getTransactions();
+        List<GetLoansLoanIdTransactions> transactions = loanDetailsResponse.getTransactions();
         List<GetLoansLoanIdTransactions> transactionsMatch = transactions.stream()
                 .filter(t -> transactionDate.equals(formatter.format(t.getDate()))
                         && transactionTypeExpected.equals(t.getType().getCode().substring(20)))
@@ -191,43 +213,25 @@ public class JournalEntriesStepDef extends AbstractStepDef {
     @Then("Reversed loan capitalized income amortization transaction has the following Journal entries:")
     public void capitalizedIncomeAmortizationJournalEntryDataCheck(final DataTable table) {
         final long capitalizedIncomeAmortizationId = testContext().get(TestContextKey.LOAN_CAPITALIZED_INCOME_AMORTIZATION_ID);
-        final Response<PostLoansResponse> loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
-        assert loanResponse.body() != null;
-        final long loanId = loanResponse.body().getLoanId();
+        final PostLoansResponse loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
+        final long loanId = loanResponse.getLoanId();
         final String resourceId = String.valueOf(loanId);
 
-        List<JournalEntryTransactionItem> journalLinesActualList;
         final String transactionId = "L" + capitalizedIncomeAmortizationId;
-        Response<GetJournalEntriesTransactionIdResponse> journalEntryDataResponse = null;
+        GetJournalEntriesTransactionIdResponse journalEntryDataResponse = null;
         try {
-            journalEntryDataResponse = journalEntriesApi.retrieveAll1(//
-                    null, //
-                    null, //
-                    null, //
-                    null, //
-                    null, //
-                    null, //
-                    null, //
-                    transactionId, //
-                    null, //
-                    null, //
-                    null, //
-                    null, //
-                    null, //
-                    null, //
-                    null, //
-                    loanId, //
-                    null, //
-                    null, //
-                    true//
-            ).execute();
-            ErrorHelper.checkSuccessfulApiCall(journalEntryDataResponse);
-        } catch (IOException e) {
+            Map<String, Object> journalQueryParams = new HashMap<>();
+            journalQueryParams.put("transactionId", transactionId);
+            journalQueryParams.put("loanId", loanId);
+            journalQueryParams.put("runningBalance", true);
+            journalEntryDataResponse = journalEntriesApi().retrieveAll1(journalQueryParams);
+        } catch (Exception e) {
             log.error("Exception", e);
         }
-        assert journalEntryDataResponse != null;
-        assert journalEntryDataResponse.body() != null;
-        journalLinesActualList = journalEntryDataResponse.body().getPageItems();
+        List<JournalEntryTransactionItem> journalLinesActualList = new ArrayList<>();
+        if (journalEntryDataResponse != null) {
+            journalLinesActualList = journalEntryDataResponse.getPageItems();
+        }
 
         final List<List<String>> data = table.asLists();
         for (int i = 1; i < data.size(); i++) {
@@ -253,7 +257,7 @@ public class JournalEntriesStepDef extends AbstractStepDef {
                 possibleActualValuesList.add(actualValues);
 
                 final boolean containsExpectedValues = possibleActualValuesList.stream()
-                        .anyMatch(actualValue -> actualValue.equals(expectedValues));
+                        .anyMatch(actualValue -> matchesWithBigDecimalComparison(actualValue, expectedValues));
                 if (containsExpectedValues) {
                     containsAnyExpected = true;
                 }
@@ -267,17 +271,18 @@ public class JournalEntriesStepDef extends AbstractStepDef {
     @Then("In Loan transactions the replayed {string} transaction with date {string} has a reverted transaction pair with the following Journal entries:")
     public void revertedJournalEntryDataCheck(String transactionType, String transactionDate, DataTable table) throws IOException {
         DateTimeFormatter formatter = DateTimeFormatter.ofPattern(DATE_FORMAT);
-        Response<PostLoansResponse> loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
-        long loanId = loanResponse.body().getLoanId();
+        PostLoansResponse loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
+        long loanId = loanResponse.getLoanId();
         String resourceId = String.valueOf(loanId);
 
-        Response<GetLoansLoanIdResponse> loanDetailsResponse = loansApi.retrieveLoan(loanId, false, "transactions", "", "").execute();
-        ErrorHelper.checkSuccessfulApiCall(loanDetailsResponse);
-
+        Map<String, Object> queryParams = new HashMap<>();
+        queryParams.put("staffInSelectedOfficeOnly", false);
+        queryParams.put("associations", "transactions");
+        GetLoansLoanIdResponse loanDetailsResponse = loansApi().retrieveLoan(loanId, queryParams);
         TransactionType transactionType1 = TransactionType.valueOf(transactionType);
         String transactionTypeExpected = transactionType1.getValue();
 
-        List<GetLoansLoanIdTransactions> transactions = loanDetailsResponse.body().getTransactions();
+        List<GetLoansLoanIdTransactions> transactions = loanDetailsResponse.getTransactions();
 
         List<GetLoansLoanIdTransactions> transactionsMatch = transactions.stream()
                 .filter(t -> transactionDate.equals(formatter.format(t.getDate()))
@@ -289,35 +294,17 @@ public class JournalEntriesStepDef extends AbstractStepDef {
                 .collect(Collectors.toList());
 
         List<List<JournalEntryTransactionItem>> journalLinesActualList = transactionIdList.stream().map(t -> {
-            Response<GetJournalEntriesTransactionIdResponse> journalEntryDataResponse = null;
+            GetJournalEntriesTransactionIdResponse journalEntryDataResponse = null;
             try {
-                journalEntryDataResponse = journalEntriesApi.retrieveAll1(//
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        t, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        true//
-                ).execute();
-                ErrorHelper.checkSuccessfulApiCall(journalEntryDataResponse);
-            } catch (IOException e) {
+                Map<String, Object> journalQueryParams = new HashMap<>();
+                journalQueryParams.put("transactionId", t);
+                journalQueryParams.put("runningBalance", true);
+                journalEntryDataResponse = journalEntriesApi().retrieveAll1(journalQueryParams);
+            } catch (Exception e) {
                 log.error("Exception", e);
             }
 
-            return journalEntryDataResponse.body().getPageItems();
+            return journalEntryDataResponse.getPageItems();
         }).collect(Collectors.toList());
 
         List<List<String>> data = table.asLists();
@@ -341,7 +328,8 @@ public class JournalEntriesStepDef extends AbstractStepDef {
                 }).collect(Collectors.toList());
                 possibleActualValuesList.add(actualValuesList);
 
-                boolean containsExpectedValues = actualValuesList.stream().anyMatch(actualValues -> actualValues.equals(expectedValues));
+                boolean containsExpectedValues = actualValuesList.stream()
+                        .anyMatch(actualValues -> matchesWithBigDecimalComparison(actualValues, expectedValues));
                 if (containsExpectedValues) {
                     containsAnyExpected = true;
                 }
@@ -355,16 +343,17 @@ public class JournalEntriesStepDef extends AbstractStepDef {
     @Then("Loan Transactions tab has a {string} transaction with date {string} has no the Journal entries")
     public void journalEntryNoDataCheck(String transactionType, String transactionDate) throws IOException {
         DateTimeFormatter formatter = DateTimeFormatter.ofPattern(DATE_FORMAT);
-        Response<PostLoansResponse> loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
-        long loanId = loanResponse.body().getLoanId();
-
-        Response<GetLoansLoanIdResponse> loanDetailsResponse = loansApi.retrieveLoan(loanId, false, "transactions", "", "").execute();
-        ErrorHelper.checkSuccessfulApiCall(loanDetailsResponse);
+        PostLoansResponse loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
+        long loanId = loanResponse.getLoanId();
 
+        Map<String, Object> queryParams = new HashMap<>();
+        queryParams.put("staffInSelectedOfficeOnly", false);
+        queryParams.put("associations", "transactions");
+        GetLoansLoanIdResponse loanDetailsResponse = loansApi().retrieveLoan(loanId, queryParams);
         TransactionType transactionType1 = TransactionType.valueOf(transactionType);
         String transactionTypeExpected = transactionType1.getValue();
 
-        List<GetLoansLoanIdTransactions> transactions = loanDetailsResponse.body().getTransactions();
+        List<GetLoansLoanIdTransactions> transactions = loanDetailsResponse.getTransactions();
         List<GetLoansLoanIdTransactions> transactionsMatch = transactions.stream()
                 .filter(t -> transactionDate.equals(formatter.format(t.getDate()))
                         && transactionTypeExpected.equals(t.getType().getCode().substring(20)))
@@ -372,58 +361,43 @@ public class JournalEntriesStepDef extends AbstractStepDef {
 
         List<List<JournalEntryTransactionItem>> journalLinesActualList = transactionsMatch.stream().map(t -> {
             String transactionId = "L" + t.getId();
-            Response<GetJournalEntriesTransactionIdResponse> journalEntryDataResponse = null;
+            GetJournalEntriesTransactionIdResponse journalEntryDataResponse = null;
             try {
-                journalEntryDataResponse = journalEntriesApi.retrieveAll1(//
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        transactionId, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        null, //
-                        true//
-                ).execute();
-                ErrorHelper.checkSuccessfulApiCall(journalEntryDataResponse);
-            } catch (IOException e) {
+                Map<String, Object> journalQueryParams = new HashMap<>();
+                journalQueryParams.put("transactionId", transactionId);
+                journalQueryParams.put("runningBalance", true);
+                journalEntryDataResponse = journalEntriesApi().retrieveAll1(journalQueryParams);
+            } catch (Exception e) {
                 log.error("Exception", e);
             }
 
-            return journalEntryDataResponse.body().getPageItems();
+            return journalEntryDataResponse.getPageItems();
         }).collect(Collectors.toList());
 
         assertThat(journalLinesActualList.stream().findFirst().get().size()).isZero();
     }
 
-    public Response<PostJournalEntriesResponse> addManualJournalEntryWithoutExternalAssetOwner(String amount, String date)
-            throws IOException {
+    public PostJournalEntriesResponse addManualJournalEntryWithoutExternalAssetOwner(String amount, String date) throws IOException {
         LocalDate transactionDate = LocalDate.parse(date, FORMATTER_EN);
         JournalEntryCommand journalEntriesRequest = loanRequestFactory.defaultManualJournalEntryRequest(new BigDecimal(amount))
                 .transactionDate(transactionDate);
-        Response<PostJournalEntriesResponse> journalEntriesResponse = journalEntriesApi.createGLJournalEntry("", journalEntriesRequest)
-                .execute();
+        Map<String, Object> createJournalQueryParams = new HashMap<>();
+        createJournalQueryParams.put("command", "");
+        PostJournalEntriesResponse journalEntriesResponse = journalEntriesApi().createGLJournalEntry(journalEntriesRequest,
+                createJournalQueryParams);
         testContext().set(TestContextKey.MANUAL_JOURNAL_ENTRIES_REQUEST, journalEntriesRequest);
         return journalEntriesResponse;
     }
 
-    public Response<PostJournalEntriesResponse> addManualJournalEntryWithExternalAssetOwner(String amount, String date,
-            String externalAssetOwner) throws IOException {
+    public PostJournalEntriesResponse addManualJournalEntryWithExternalAssetOwner(String amount, String date, String externalAssetOwner)
+            throws IOException {
         LocalDate transactionDate = LocalDate.parse(date, FORMATTER_EN);
         JournalEntryCommand journalEntriesRequest = loanRequestFactory
                 .defaultManualJournalEntryRequest(new BigDecimal(amount), externalAssetOwner).transactionDate(transactionDate);
-        Response<PostJournalEntriesResponse> journalEntriesResponse = journalEntriesApi.createGLJournalEntry("", journalEntriesRequest)
-                .execute();
+        Map<String, Object> createJournalQueryParams = new HashMap<>();
+        createJournalQueryParams.put("command", "");
+        PostJournalEntriesResponse journalEntriesResponse = journalEntriesApi().createGLJournalEntry(journalEntriesRequest,
+                createJournalQueryParams);
         testContext().set(TestContextKey.MANUAL_JOURNAL_ENTRIES_REQUEST, journalEntriesRequest);
         return journalEntriesResponse;
     }
@@ -431,62 +405,41 @@ public class JournalEntriesStepDef extends AbstractStepDef {
     @Then("Admin creates manual Journal entry with {string} amount and {string} date and unique External Asset Owner")
     public void createManualJournalEntryWithExternalAssetOwner(String amount, String date) throws IOException {
         String ownerExternalIdStored = testContext().get(TestContextKey.ASSET_EXTERNALIZATION_OWNER_EXTERNAL_ID);
-        Response<PostJournalEntriesResponse> journalEntriesResponse = addManualJournalEntryWithExternalAssetOwner(amount, date,
+        PostJournalEntriesResponse journalEntriesResponse = addManualJournalEntryWithExternalAssetOwner(amount, date,
                 ownerExternalIdStored);
 
         testContext().set(TestContextKey.MANUAL_JOURNAL_ENTRIES_RESPONSE, journalEntriesResponse);
-        ErrorHelper.checkSuccessfulApiCall(journalEntriesResponse);
     }
 
     @Then("Admin creates manual Journal entry with {string} amount and {string} date and empty External Asset Owner")
     public void createManualJournalEntryWithEmptyExternalAssetOwner(String amount, String date) throws IOException {
-        Response<PostJournalEntriesResponse> journalEntriesResponse = addManualJournalEntryWithExternalAssetOwner(amount, date, "");
+        PostJournalEntriesResponse journalEntriesResponse = addManualJournalEntryWithExternalAssetOwner(amount, date, "");
 
         testContext().set(TestContextKey.MANUAL_JOURNAL_ENTRIES_RESPONSE, journalEntriesResponse);
-        ErrorHelper.checkSuccessfulApiCall(journalEntriesResponse);
     }
 
     @Then("Admin creates manual Journal entry with {string} amount and {string} date and without External Asset Owner")
     public void createManualJournalEntryWithoutExternalAssetOwner(String amount, String date) throws IOException {
-        Response<PostJournalEntriesResponse> journalEntriesResponse = addManualJournalEntryWithoutExternalAssetOwner(amount, date);
+        PostJournalEntriesResponse journalEntriesResponse = addManualJournalEntryWithoutExternalAssetOwner(amount, date);
 
         testContext().set(TestContextKey.MANUAL_JOURNAL_ENTRIES_RESPONSE, journalEntriesResponse);
-        ErrorHelper.checkSuccessfulApiCall(journalEntriesResponse);
     }
 
     @Then("Verify manual Journal entry with External Asset Owner {string} and with the following Journal entries:")
     public void checkManualJournalEntry(String externalAssetOwnerEnabled, DataTable table) {
-        Response<PostJournalEntriesResponse> journalEnriesResponse = testContext().get(TestContextKey.MANUAL_JOURNAL_ENTRIES_RESPONSE);
-        PostJournalEntriesResponse journalEntriesResponseBody = journalEnriesResponse.body();
+        PostJournalEntriesResponse journalEnriesResponse = testContext().get(TestContextKey.MANUAL_JOURNAL_ENTRIES_RESPONSE);
+        PostJournalEntriesResponse journalEntriesResponseBody = journalEnriesResponse;
         String transactionId = journalEntriesResponseBody.getTransactionId();
 
         JournalEntryCommand journalEntriesRequest = testContext().get(TestContextKey.MANUAL_JOURNAL_ENTRIES_REQUEST);
 
-        Response<GetJournalEntriesTransactionIdResponse> journalEntryDataResponse = null;
+        GetJournalEntriesTransactionIdResponse journalEntryDataResponse = null;
         try {
-            journalEntryDataResponse = journalEntriesApi.retrieveAll1(//
-                    null, //
-                    null, //
-                    null, //
-                    null, //
-                    null, //
-                    null, //
-                    null, //
-                    transactionId, //
-                    null, //
-                    null, //
-                    null, //
-                    null, //
-                    null, //
-                    null, //
-                    null, //
-                    null, //
-                    null, //
-                    null, //
-                    true//
-            ).execute();
-            ErrorHelper.checkSuccessfulApiCall(journalEntryDataResponse);
-        } catch (IOException e) {
+            Map<String, Object> journalQueryParams = new HashMap<>();
+            journalQueryParams.put("transactionId", transactionId);
+            journalQueryParams.put("runningBalance", true);
+            journalEntryDataResponse = journalEntriesApi().retrieveAll1(journalQueryParams);
+        } catch (Exception e) {
             log.error("Exception", e);
         }
 
@@ -500,7 +453,7 @@ public class JournalEntriesStepDef extends AbstractStepDef {
             }
             boolean containsAnyExpected = false;
 
-            GetJournalEntriesTransactionIdResponse journalEntryData = journalEntryDataResponse.body();
+            GetJournalEntriesTransactionIdResponse journalEntryData = journalEntryDataResponse;
 
             List<JournalEntryTransactionItem> journalLinesActual = journalEntryData.getPageItems();
 
@@ -511,7 +464,7 @@ public class JournalEntriesStepDef extends AbstractStepDef {
                 actualValues.add(t.getGlAccountName() == null ? null : t.getGlAccountName());
                 actualValues.add("DEBIT".equals(t.getEntryType().getValue()) ? String.valueOf(t.getAmount()) : null);
                 actualValues.add("CREDIT".equals(t.getEntryType().getValue()) ? String.valueOf(t.getAmount()) : null);
-                actualValues.add(String.valueOf(t.getManualEntry()).toLowerCase());
+                actualValues.add(String.valueOf(t.getManualEntry()).toLowerCase(Locale.ROOT));
                 if (Boolean.parseBoolean(externalAssetOwnerEnabled)) {
                     actualValues.add(t.getExternalAssetOwner() == null ? null : t.getExternalAssetOwner());
                 }
@@ -521,7 +474,8 @@ public class JournalEntriesStepDef extends AbstractStepDef {
 
             possibleActualValuesList.add(actualValuesList);
 
-            boolean containsExpectedValues = actualValuesList.stream().anyMatch(actualValues -> actualValues.equals(expectedValues));
+            boolean containsExpectedValues = actualValuesList.stream()
+                    .anyMatch(actualValues -> matchesWithBigDecimalComparison(actualValues, expectedValues));
             if (containsExpectedValues) {
                 containsAnyExpected = true;
             }
