@@ -18,9 +18,9 @@
  */
 package org.apache.fineract.test.stepdef.loan;
 
+import static org.apache.fineract.client.feign.util.FeignCalls.ok;
 import static org.assertj.core.api.Assertions.assertThat;
 
-import com.google.gson.Gson;
 import io.cucumber.datatable.DataTable;
 import io.cucumber.java.en.And;
 import io.cucumber.java.en.Then;
@@ -29,8 +29,11 @@ import java.io.IOException;
 import java.math.BigDecimal;
 import java.time.format.DateTimeFormatter;
 import java.util.List;
+import java.util.Map;
 import lombok.extern.slf4j.Slf4j;
 import org.apache.fineract.avro.loan.v1.LoanChargeDataV1;
+import org.apache.fineract.client.feign.FeignException;
+import org.apache.fineract.client.feign.FineractFeignClient;
 import org.apache.fineract.client.models.GetLoansLoanIdChargesChargeIdResponse;
 import org.apache.fineract.client.models.GetLoansLoanIdResponse;
 import org.apache.fineract.client.models.GetLoansLoanIdTransactions;
@@ -41,14 +44,9 @@ import org.apache.fineract.client.models.PostLoansLoanIdChargesResponse;
 import org.apache.fineract.client.models.PostLoansResponse;
 import org.apache.fineract.client.models.PutChargeTransactionChangesRequest;
 import org.apache.fineract.client.models.PutChargeTransactionChangesResponse;
-import org.apache.fineract.client.services.LoanChargesApi;
-import org.apache.fineract.client.services.LoanTransactionsApi;
-import org.apache.fineract.client.services.LoansApi;
-import org.apache.fineract.client.util.JSON;
 import org.apache.fineract.test.data.ChargeProductType;
 import org.apache.fineract.test.data.ErrorMessageType;
 import org.apache.fineract.test.factory.LoanChargeRequestFactory;
-import org.apache.fineract.test.helper.ErrorHelper;
 import org.apache.fineract.test.helper.ErrorMessageHelper;
 import org.apache.fineract.test.helper.ErrorResponse;
 import org.apache.fineract.test.messaging.EventAssertion;
@@ -58,7 +56,6 @@ import org.apache.fineract.test.messaging.store.EventStore;
 import org.apache.fineract.test.stepdef.AbstractStepDef;
 import org.apache.fineract.test.support.TestContextKey;
 import org.springframework.beans.factory.annotation.Autowired;
-import retrofit2.Response;
 
 @Slf4j
 public class LoanChargeStepDef extends AbstractStepDef {
@@ -66,14 +63,10 @@ public class LoanChargeStepDef extends AbstractStepDef {
     public static final String DEFAULT_DATE_FORMAT = "dd MMMM yyyy";
     public static final String DATE_FORMAT_EVENTS = "yyyy-MM-dd";
     public static final Double DEFAULT_CHARGE_FEE_FLAT = 10D;
-    private static final Gson GSON = new JSON().getGson();
 
     @Autowired
-    private LoanChargesApi loanChargesApi;
-    @Autowired
-    private LoanTransactionsApi loanTransactionsApi;
-    @Autowired
-    private LoansApi loansApi;
+    private FineractFeignClient fineractClient;
+
     @Autowired
     private EventAssertion eventAssertion;
     @Autowired
@@ -83,8 +76,8 @@ public class LoanChargeStepDef extends AbstractStepDef {
 
     @When("Admin adds {string} due date charge with {string} due date and {double} EUR transaction amount")
     public void addChargeDueDate(String chargeType, String transactionDate, double transactionAmount) throws IOException {
-        Response<PostLoansResponse> loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
-        long loanId = loanResponse.body().getLoanId();
+        PostLoansResponse loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
+        long loanId = loanResponse.getLoanId();
 
         ChargeProductType chargeProductType = ChargeProductType.valueOf(chargeType);
         Long chargeTypeId = chargeProductType.getValue();
@@ -97,9 +90,8 @@ public class LoanChargeStepDef extends AbstractStepDef {
         PostLoansLoanIdChargesRequest loanIdChargesRequest = LoanChargeRequestFactory.defaultLoanChargeRequest().chargeId(chargeTypeId)
                 .dueDate(transactionDate).amount(transactionAmount);
 
-        Response<PostLoansLoanIdChargesResponse> loanChargeResponse = loanChargesApi.executeLoanCharge(loanId, loanIdChargesRequest, "")
-                .execute();
-        ErrorHelper.checkSuccessfulApiCall(loanChargeResponse);
+        PostLoansLoanIdChargesResponse loanChargeResponse = ok(
+                () -> fineractClient.loanCharges().executeLoanCharge(loanId, loanIdChargesRequest, Map.<String, Object>of()));
         testContext().set(TestContextKey.ADD_DUE_DATE_CHARGE_RESPONSE, loanChargeResponse);
         testContext().set(TestContextKey.ADD_NSF_FEE_RESPONSE, loanChargeResponse);
 
@@ -108,8 +100,8 @@ public class LoanChargeStepDef extends AbstractStepDef {
 
     @When("Admin adds {string} charge with {double} % of transaction amount")
     public void addChargePercentage(String chargeType, double transactionPercentageAmount) throws IOException {
-        Response<PostLoansResponse> loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
-        long loanId = loanResponse.body().getLoanId();
+        PostLoansResponse loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
+        long loanId = loanResponse.getLoanId();
 
         ChargeProductType chargeProductType = ChargeProductType.valueOf(chargeType);
         Long chargeTypeId = chargeProductType.getValue();
@@ -123,17 +115,16 @@ public class LoanChargeStepDef extends AbstractStepDef {
         PostLoansLoanIdChargesRequest loanIdChargesRequest = LoanChargeRequestFactory.defaultLoanChargeRequest().chargeId(chargeTypeId)
                 .amount(transactionPercentageAmount);
 
-        Response<PostLoansLoanIdChargesResponse> loanChargeResponse = loanChargesApi.executeLoanCharge(loanId, loanIdChargesRequest, "")
-                .execute();
-        ErrorHelper.checkSuccessfulApiCall(loanChargeResponse);
+        PostLoansLoanIdChargesResponse loanChargeResponse = ok(
+                () -> fineractClient.loanCharges().executeLoanCharge(loanId, loanIdChargesRequest, Map.<String, Object>of()));
         testContext().set(TestContextKey.ADD_DUE_DATE_CHARGE_RESPONSE, loanChargeResponse);
     }
 
     @When("Admin adds {string} installment charge with {double} amount")
     public void addInstallmentFeeCharge(final String chargeType, final double amount) throws IOException {
-        final Response<PostLoansResponse> loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
-        assert loanResponse.body() != null;
-        final long loanId = loanResponse.body().getLoanId();
+        final PostLoansResponse loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
+        assert loanResponse != null;
+        final long loanId = loanResponse.getLoanId();
 
         final ChargeProductType chargeProductType = ChargeProductType.valueOf(chargeType);
         final Long chargeTypeId = chargeProductType.getValue();
@@ -148,39 +139,40 @@ public class LoanChargeStepDef extends AbstractStepDef {
         final PostLoansLoanIdChargesRequest loanIdChargesRequest = LoanChargeRequestFactory.defaultLoanChargeRequest()
                 .chargeId(chargeTypeId).amount(amount);
 
-        final Response<PostLoansLoanIdChargesResponse> loanChargeResponse = loanChargesApi
-                .executeLoanCharge(loanId, loanIdChargesRequest, "").execute();
-        ErrorHelper.checkSuccessfulApiCall(loanChargeResponse);
+        final PostLoansLoanIdChargesResponse loanChargeResponse = ok(
+                () -> fineractClient.loanCharges().executeLoanCharge(loanId, loanIdChargesRequest, Map.<String, Object>of()));
         testContext().set(TestContextKey.ADD_INSTALLMENT_FEE_CHARGE_RESPONSE, loanChargeResponse);
     }
 
     @Then("Admin fails to add {string} installment charge with {double} amount because of wrong charge calculation type")
     public void addInstallmentFeeChargeFails(final String chargeType, final double amount) throws IOException {
-        final Response<PostLoansResponse> loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
-        assert loanResponse.body() != null;
+        final PostLoansResponse loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
+        assert loanResponse != null;
 
-        final long loanId = loanResponse.body().getLoanId();
+        final long loanId = loanResponse.getLoanId();
         final ChargeProductType chargeProductType = ChargeProductType.valueOf(chargeType);
         final Long chargeTypeId = chargeProductType.getValue();
 
         final PostLoansLoanIdChargesRequest loanIdChargesRequest = LoanChargeRequestFactory.defaultLoanChargeRequest()
                 .chargeId(chargeTypeId).amount(amount);
 
-        final Response<PostLoansLoanIdChargesResponse> loanChargeResponse = loanChargesApi
-                .executeLoanCharge(loanId, loanIdChargesRequest, "").execute();
-        testContext().set(TestContextKey.ADD_INSTALLMENT_FEE_CHARGE_RESPONSE, loanChargeResponse);
-        final ErrorResponse errorDetails = ErrorResponse.from(loanChargeResponse);
-        assertThat(errorDetails.getHttpStatusCode()).isEqualTo(400);
-        assertThat(errorDetails.getSingleError().getDeveloperMessage())
-                .isEqualTo(chargeProductType.equals(ChargeProductType.LOAN_INSTALLMENT_FEE_PERCENTAGE_INTEREST)
-                        ? ErrorMessageHelper.addInstallmentFeeInterestPercentageChargeFailure()
-                        : ErrorMessageHelper.addInstallmentFeePrincipalPercentageChargeFailure());
+        try {
+            fineractClient.loanCharges().executeLoanCharge(loanId, loanIdChargesRequest, Map.<String, Object>of());
+            throw new AssertionError("Expected FeignException but request succeeded");
+        } catch (FeignException e) {
+            final ErrorResponse errorDetails = ErrorResponse.fromFeignException(e);
+            assertThat(errorDetails.getHttpStatusCode()).isEqualTo(400);
+            String expectedMessage = chargeTypeId.equals(ChargeProductType.LOAN_INSTALLMENT_FEE_PERCENTAGE_INTEREST.getValue())
+                    ? ErrorMessageHelper.addInstallmentFeeInterestPercentageChargeFailure()
+                    : ErrorMessageHelper.addInstallmentFeePrincipalPercentageChargeFailure();
+            assertThat(errorDetails.getSingleError().getDeveloperMessage()).contains(expectedMessage);
+        }
     }
 
     @Then("Admin is not able to add {string} due date charge with {string} due date and {double} EUR transaction amount because the of charged-off account")
     public void addChargeDueDateOnChargedOff(String chargeType, String transactionDate, double transactionAmount) throws IOException {
-        Response<PostLoansResponse> loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
-        long loanId = loanResponse.body().getLoanId();
+        PostLoansResponse loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
+        long loanId = loanResponse.getLoanId();
 
         ChargeProductType chargeProductType = ChargeProductType.valueOf(chargeType);
         Long chargeTypeId = chargeProductType.getValue();
@@ -188,27 +180,28 @@ public class LoanChargeStepDef extends AbstractStepDef {
         PostLoansLoanIdChargesRequest loanIdChargesRequest = LoanChargeRequestFactory.defaultLoanChargeRequest().chargeId(chargeTypeId)
                 .dueDate(transactionDate).amount(transactionAmount);
 
-        Response<PostLoansLoanIdChargesResponse> loanChargeResponse = loanChargesApi.executeLoanCharge(loanId, loanIdChargesRequest, "")
-                .execute();
-        testContext().set(TestContextKey.ADD_DUE_DATE_CHARGE_RESPONSE, loanChargeResponse);
-        ErrorResponse errorDetails = ErrorResponse.from(loanChargeResponse);
-        assertThat(errorDetails.getHttpStatusCode()).as(ErrorMessageHelper.addChargeForChargeOffLoanCodeMsg()).isEqualTo(403);
-        assertThat(errorDetails.getSingleError().getDeveloperMessage())
-                .isEqualTo(ErrorMessageHelper.addChargeForChargeOffLoanFailure(loanId));
+        try {
+            fineractClient.loanCharges().executeLoanCharge(loanId, loanIdChargesRequest, Map.<String, Object>of());
+            throw new AssertionError("Expected FeignException but request succeeded");
+        } catch (FeignException e) {
+            ErrorResponse errorDetails = ErrorResponse.fromFeignException(e);
+            assertThat(errorDetails.getHttpStatusCode()).as(ErrorMessageHelper.addChargeForChargeOffLoanCodeMsg()).isEqualTo(403);
+            assertThat(errorDetails.getSingleError().getDeveloperMessage())
+                    .contains(ErrorMessageHelper.addChargeForChargeOffLoanFailure(loanId));
+        }
     }
 
     @And("Admin adds a {double} % Processing charge to the loan with {string} locale on date: {string}")
     public void addProcessingFee(double chargeAmount, String locale, String date) throws IOException {
         eventStore.reset();
-        Response<PostLoansResponse> loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
-        long loanId = loanResponse.body().getLoanId();
+        PostLoansResponse loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
+        long loanId = loanResponse.getLoanId();
         PostLoansLoanIdChargesRequest loanIdChargesRequest = LoanChargeRequestFactory.defaultLoanChargeRequest()
                 .chargeId(ChargeProductType.LOAN_PERCENTAGE_PROCESSING_FEE.value).amount(chargeAmount).dueDate(date)
                 .dateFormat(DEFAULT_DATE_FORMAT).locale(locale);
 
-        Response<PostLoansLoanIdChargesResponse> loanChargeResponse = loanChargesApi.executeLoanCharge(loanId, loanIdChargesRequest, "")
-                .execute();
-        ErrorHelper.checkSuccessfulApiCall(loanChargeResponse);
+        PostLoansLoanIdChargesResponse loanChargeResponse = ok(
+                () -> fineractClient.loanCharges().executeLoanCharge(loanId, loanIdChargesRequest, Map.<String, Object>of()));
         testContext().set(TestContextKey.ADD_PROCESSING_FEE_RESPONSE, loanChargeResponse);
         eventCheckHelper.loanBalanceChangedEventCheck(loanId);
     }
@@ -216,102 +209,91 @@ public class LoanChargeStepDef extends AbstractStepDef {
     @And("Admin adds an NSF fee because of payment bounce with {string} transaction date")
     public void addNSFfee(String date) throws IOException {
         eventStore.reset();
-        Response<PostLoansResponse> loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
-        long loanId = loanResponse.body().getLoanId();
+        PostLoansResponse loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
+        long loanId = loanResponse.getLoanId();
         PostLoansLoanIdChargesRequest loanIdChargesRequest = LoanChargeRequestFactory.defaultLoanChargeRequest()
                 .chargeId(ChargeProductType.LOAN_NSF_FEE.value).amount(DEFAULT_CHARGE_FEE_FLAT).dueDate(date)
                 .dateFormat(DEFAULT_DATE_FORMAT);
 
-        Response<PostLoansLoanIdChargesResponse> loanChargeResponse = loanChargesApi.executeLoanCharge(loanId, loanIdChargesRequest, "")
-                .execute();
-        ErrorHelper.checkSuccessfulApiCall(loanChargeResponse);
+        PostLoansLoanIdChargesResponse loanChargeResponse = ok(
+                () -> fineractClient.loanCharges().executeLoanCharge(loanId, loanIdChargesRequest, Map.<String, Object>of()));
         testContext().set(TestContextKey.ADD_NSF_FEE_RESPONSE, loanChargeResponse);
         eventCheckHelper.loanBalanceChangedEventCheck(loanId);
     }
 
     @And("Admin waives charge")
     public void waiveCharge() throws IOException {
-        Response<PostLoansResponse> loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
-        long loanId = loanResponse.body().getLoanId();
+        PostLoansResponse loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
+        long loanId = loanResponse.getLoanId();
 
-        Response<PostLoansLoanIdChargesResponse> loanChargeResponse = testContext().get(TestContextKey.ADD_NSF_FEE_RESPONSE);
-        Long chargeId = Long.valueOf(loanChargeResponse.body().getResourceId());
+        PostLoansLoanIdChargesResponse loanChargeResponse = testContext().get(TestContextKey.ADD_NSF_FEE_RESPONSE);
+        Long chargeId = Long.valueOf(loanChargeResponse.getResourceId());
 
         PostLoansLoanIdChargesChargeIdRequest waiveRequest = new PostLoansLoanIdChargesChargeIdRequest();
 
-        Response<PostLoansLoanIdChargesChargeIdResponse> waiveResponse = loanChargesApi
-                .executeLoanCharge2(loanId, chargeId, waiveRequest, "waive").execute();
-        ErrorHelper.checkSuccessfulApiCall(waiveResponse);
+        PostLoansLoanIdChargesChargeIdResponse waiveResponse = ok(() -> fineractClient.loanCharges().executeLoanCharge2(loanId, chargeId,
+                waiveRequest, Map.<String, Object>of("command", "waive")));
         testContext().set(TestContextKey.WAIVE_CHARGE_RESPONSE, waiveResponse);
     }
 
     @And("Admin waives due date charge")
     public void waiveDueDateCharge() throws IOException {
-        Response<PostLoansResponse> loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
-        long loanId = loanResponse.body().getLoanId();
+        PostLoansResponse loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
+        long loanId = loanResponse.getLoanId();
 
-        Response<PostLoansLoanIdChargesResponse> loanChargeResponse = testContext().get(TestContextKey.ADD_DUE_DATE_CHARGE_RESPONSE);
-        Long chargeId = Long.valueOf(loanChargeResponse.body().getResourceId());
+        PostLoansLoanIdChargesResponse loanChargeResponse = testContext().get(TestContextKey.ADD_DUE_DATE_CHARGE_RESPONSE);
+        Long chargeId = Long.valueOf(loanChargeResponse.getResourceId());
 
         PostLoansLoanIdChargesChargeIdRequest waiveRequest = new PostLoansLoanIdChargesChargeIdRequest();
 
-        Response<PostLoansLoanIdChargesChargeIdResponse> waiveResponse = loanChargesApi
-                .executeLoanCharge2(loanId, chargeId, waiveRequest, "waive").execute();
-        ErrorHelper.checkSuccessfulApiCall(waiveResponse);
+        PostLoansLoanIdChargesChargeIdResponse waiveResponse = ok(() -> fineractClient.loanCharges().executeLoanCharge2(loanId, chargeId,
+                waiveRequest, Map.<String, Object>of("command", "waive")));
         testContext().set(TestContextKey.WAIVE_CHARGE_RESPONSE, waiveResponse);
     }
 
     @And("Admin makes waive undone for charge")
     public void undoWaiveForCharge() throws IOException {
-        Response<PostLoansResponse> loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
-        long loanId = loanResponse.body().getLoanId();
+        PostLoansResponse loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
+        long loanId = loanResponse.getLoanId();
 
-        Response<GetLoansLoanIdResponse> loanDetails = loansApi.retrieveLoan(loanId, false, "transactions", "", "").execute();
-        List<GetLoansLoanIdTransactions> transactions = loanDetails.body().getTransactions();
+        GetLoansLoanIdResponse loanDetails = ok(
+                () -> fineractClient.loans().retrieveLoan(loanId, Map.<String, Object>of("associations", "transactions")));
+        List<GetLoansLoanIdTransactions> transactions = loanDetails.getTransactions();
 
-        Long transactionId = 0L;
-        for (GetLoansLoanIdTransactions f : transactions) {
-            String code = f.getType().getCode();
-            if (code.equals("loanTransactionType.waiveCharges")) {
-                transactionId = f.getId();
-            }
-        }
+        final Long transactionId = transactions.stream().filter(t -> "loanTransactionType.waiveCharges".equals(t.getType().getCode()))
+                .findFirst().map(GetLoansLoanIdTransactions::getId).orElse(0L);
 
         PutChargeTransactionChangesRequest undoWaiveRequest = new PutChargeTransactionChangesRequest();
-        Response<PutChargeTransactionChangesResponse> undoWaiveResponse = loanTransactionsApi
-                .undoWaiveCharge(loanId, transactionId, undoWaiveRequest).execute();
-        ErrorHelper.checkSuccessfulApiCall(undoWaiveResponse);
+        PutChargeTransactionChangesResponse undoWaiveResponse = ok(
+                () -> fineractClient.loanTransactions().undoWaiveCharge(loanId, transactionId, undoWaiveRequest));
         testContext().set(TestContextKey.UNDO_WAIVE_RESPONSE, undoWaiveResponse);
     }
 
     @Then("Charge is successfully added to the loan")
     public void loanChargeStatus() throws IOException {
-        Response<PostLoansLoanIdChargesResponse> response = testContext().get(TestContextKey.ADD_NSF_FEE_RESPONSE);
+        PostLoansLoanIdChargesResponse response = testContext().get(TestContextKey.ADD_NSF_FEE_RESPONSE);
 
-        assertThat(response.isSuccessful()).as(ErrorMessageHelper.requestFailed(response)).isTrue();
-        assertThat(response.code()).as(ErrorMessageHelper.requestFailedWithCode(response)).isEqualTo(200);
+        assertThat(response).as("Charge response should not be null").isNotNull();
+        assertThat(response.getResourceId()).as("Charge resource ID should be present").isNotNull();
     }
 
     @Then("Charge is successfully added to the loan with {float} EUR")
     public void checkLoanChargeAmount(float chargeAmount) throws IOException {
-        Response<PostLoansLoanIdChargesResponse> response = testContext().get(TestContextKey.ADD_PROCESSING_FEE_RESPONSE);
-        Response<GetLoansLoanIdChargesChargeIdResponse> loanChargeAmount = loanChargesApi
-                .retrieveLoanCharge(response.body().getLoanId(), Long.valueOf(response.body().getResourceId())).execute();
-
-        ErrorHelper.checkSuccessfulApiCall(response);
-        assertThat(loanChargeAmount.body().getAmount()).as("Charge amount is wrong").isEqualTo(chargeAmount);
+        PostLoansLoanIdChargesResponse response = testContext().get(TestContextKey.ADD_PROCESSING_FEE_RESPONSE);
+        GetLoansLoanIdChargesChargeIdResponse loanChargeAmount = ok(
+                () -> fineractClient.loanCharges().retrieveLoanCharge(response.getLoanId(), Long.valueOf(response.getResourceId())));
+        assertThat(loanChargeAmount.getAmount()).as("Charge amount is wrong").isEqualByComparingTo(Double.valueOf(chargeAmount));
     }
 
-    private void addChargeEventCheck(Response<PostLoansLoanIdChargesResponse> loanChargeResponse) throws IOException {
+    private void addChargeEventCheck(PostLoansLoanIdChargesResponse loanChargeResponse) throws IOException {
         DateTimeFormatter formatter = DateTimeFormatter.ofPattern(DATE_FORMAT_EVENTS);
-        Response<GetLoansLoanIdChargesChargeIdResponse> chargeDetails = loanChargesApi
-                .retrieveLoanCharge(loanChargeResponse.body().getLoanId(), loanChargeResponse.body().getResourceId()).execute();
-        GetLoansLoanIdChargesChargeIdResponse body = chargeDetails.body();
+        GetLoansLoanIdChargesChargeIdResponse chargeDetails = ok(
+                () -> fineractClient.loanCharges().retrieveLoanCharge(loanChargeResponse.getLoanId(), loanChargeResponse.getResourceId()));
+        GetLoansLoanIdChargesChargeIdResponse body = chargeDetails;
 
-        eventAssertion.assertEvent(LoanAddChargeEvent.class, loanChargeResponse.body().getResourceId())
-                .extractingData(LoanChargeDataV1::getName).isEqualTo(body.getName()).extractingBigDecimal(LoanChargeDataV1::getAmount)
-                .isEqualTo(BigDecimal.valueOf(body.getAmount())).extractingData(LoanChargeDataV1::getDueDate)
-                .isEqualTo(formatter.format(body.getDueDate()));
+        eventAssertion.assertEvent(LoanAddChargeEvent.class, loanChargeResponse.getResourceId()).extractingData(LoanChargeDataV1::getName)
+                .isEqualTo(body.getName()).extractingBigDecimal(LoanChargeDataV1::getAmount).isEqualTo(BigDecimal.valueOf(body.getAmount()))
+                .extractingData(LoanChargeDataV1::getDueDate).isEqualTo(formatter.format(body.getDueDate()));
     }
 
     @Then("Loan charge transaction with the following data results a {int} error and {string} error message")
@@ -322,8 +304,8 @@ public class LoanChargeStepDef extends AbstractStepDef {
         String transactionDate = chargeData.get(1);
         Double transactionAmount = Double.valueOf(chargeData.get(2));
 
-        Response<PostLoansResponse> loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
-        long loanId = loanResponse.body().getLoanId();
+        PostLoansResponse loanResponse = testContext().get(TestContextKey.LOAN_CREATE_RESPONSE);
+        long loanId = loanResponse.getLoanId();
 
         ErrorMessageType errorMsgType = ErrorMessageType.valueOf(errorMessageType);
         String errorMessageExpectedRaw = errorMsgType.getValue();
@@ -340,18 +322,21 @@ public class LoanChargeStepDef extends AbstractStepDef {
         PostLoansLoanIdChargesRequest loanIdChargesRequest = LoanChargeRequestFactory.defaultLoanChargeRequest().chargeId(chargeTypeId)
                 .dueDate(transactionDate).amount(transactionAmount);
 
-        Response<PostLoansLoanIdChargesResponse> loanChargeResponse = loanChargesApi.executeLoanCharge(loanId, loanIdChargesRequest, "")
-                .execute();
-        int errorCodeActual = loanChargeResponse.code();
-        String errorBody = loanChargeResponse.errorBody().string();
-        ErrorResponse errorResponse = GSON.fromJson(errorBody, ErrorResponse.class);
-        String errorMessageActual = errorResponse.getErrors().get(0).getDeveloperMessage();
+        try {
+            fineractClient.loanCharges().executeLoanCharge(loanId, loanIdChargesRequest, Map.<String, Object>of());
+            throw new AssertionError("Expected FeignException but request succeeded");
+        } catch (FeignException e) {
+            ErrorResponse errorResponse = ErrorResponse.fromFeignException(e);
+            int errorCodeActual = errorResponse.getHttpStatusCode();
+            String errorMessageActual = errorResponse.getErrors().get(0).getDeveloperMessage();
 
-        assertThat(errorCodeActual).as(ErrorMessageHelper.wrongErrorCode(errorCodeActual, errorCodeExpected)).isEqualTo(errorCodeExpected);
-        assertThat(errorMessageActual).as(ErrorMessageHelper.wrongErrorMessage(errorMessageActual, errorMessageExpected))
-                .isEqualTo(errorMessageExpected);
+            assertThat(errorCodeActual).as(ErrorMessageHelper.wrongErrorCode(errorCodeActual, errorCodeExpected))
+                    .isEqualTo(errorCodeExpected);
+            assertThat(errorMessageActual).as(ErrorMessageHelper.wrongErrorMessage(errorMessageActual, errorMessageExpected))
+                    .contains(errorMessageExpected);
 
-        log.debug("ERROR CODE: {}", errorCodeActual);
-        log.debug("ERROR MESSAGE: {}", errorMessageActual);
+            log.debug("ERROR CODE: {}", errorCodeActual);
+            log.debug("ERROR MESSAGE: {}", errorMessageActual);
+        }
     }
 }
