@@ -18,23 +18,17 @@
  */
 package org.apache.fineract.portfolio.loanaccount.service;
 
-import java.time.LocalDate;
 import java.util.List;
 import org.apache.fineract.portfolio.loanaccount.domain.Loan;
-import org.apache.fineract.portfolio.loanaccount.domain.LoanCharge;
 import org.apache.fineract.portfolio.loanaccount.domain.LoanTransaction;
 
 public interface ReprocessLoanTransactionsService {
 
     void reprocessTransactions(Loan loan);
 
-    void reprocessParticularTransactions(Loan loan, List<LoanTransaction> loanTransactions);
+    void reprocessTransactions(Loan loan, List<LoanTransaction> loanTransactions);
 
-    void reprocessTransactionsWithPostTransactionChecks(Loan loan, LocalDate transactionDate);
-
-    void processPostDisbursementTransactions(Loan loan);
-
-    void removeLoanCharge(Loan loan, LoanCharge loanCharge);
+    void reprocessTransactionsWithoutChecks(Loan loan, List<LoanTransaction> newTransactions);
 
     void processLatestTransaction(LoanTransaction loanTransaction, Loan loan);
 
