@@ -309,6 +309,8 @@ public final class LoanProductsApiResourceSwagger {
         // Multi Disburse
         @Schema(example = "true")
         public Boolean multiDisburseLoan;
+        @Schema(example = "false", description = "Allow full term length for each tranche disbursement. Only available for PROGRESSIVE schedule type with multi-disbursement enabled.")
+        public Boolean allowFullTermForTranche;
         @Schema(example = "50")
         public Integer principalThresholdForLastInstallment;
         @Schema(example = "true")
@@ -1346,25 +1348,9 @@ public final class LoanProductsApiResourceSwagger {
 
             private GetChargeOffReasonToExpenseAccountMappings() {}
 
-            public GetCodeValueData chargeOffReasonCodeValue;
+            public GetCodeValuesDataResponse reasonCodeValue;
             public GetGLAccountData expenseAccount;
 
-            static final class GetCodeValueData {
-
-                private GetCodeValueData() {}
-
-                @Schema(example = "1")
-                public Long id;
-                @Schema(example = "ChargeOffReasons")
-                public String name;
-                @Schema(example = "1")
-                public Integer position;
-                public String description;
-                @Schema(example = "true")
-                public Boolean active;
-                @Schema(example = "false")
-                public Boolean mandatory;
-            }
         }
 
         static final class GetLoanFeeToIncomeAccountMappings {
@@ -1492,11 +1478,13 @@ public final class LoanProductsApiResourceSwagger {
         public Set<GetLoanPaymentChannelToFundSourceMappings> paymentChannelToFundSourceMappings;
         public Set<GetLoanFeeToIncomeAccountMappings> feeToIncomeAccountMappings;
         public List<GetChargeOffReasonToExpenseAccountMappings> chargeOffReasonToExpenseAccountMappings;
-        public List<PostLoanProductsRequest.PostWriteOffReasonToExpenseAccountMappings> writeOffReasonsToExpenseMappings;
+        public List<GetChargeOffReasonToExpenseAccountMappings> writeOffReasonsToExpenseMappings;
         @Schema(example = "false")
         public Boolean isRatesEnabled;
         @Schema(example = "true")
         public Boolean multiDisburseLoan;
+        @Schema(example = "false", description = "Allow full term length for each tranche disbursement. Only available for PROGRESSIVE schedule type with multi-disbursement enabled.")
+        public Boolean allowFullTermForTranche;
         @Schema(example = "3")
         public Integer maxTrancheCount;
         @Schema(example = "36000.000000")
@@ -1810,6 +1798,8 @@ public final class LoanProductsApiResourceSwagger {
         // Multi Disburse
         @Schema(example = "true")
         public Boolean multiDisburseLoan;
+        @Schema(example = "false", description = "Allow full term length for each tranche disbursement. Only available for PROGRESSIVE schedule type with multi-disbursement enabled.")
+        public Boolean allowFullTermForTranche;
         @Schema(example = "50")
         public Integer principalThresholdForLastInstallment;
         @Schema(example = "true")
