@@ -37,7 +37,6 @@ import org.apache.fineract.organisation.monetary.domain.MonetaryCurrency;
 import org.apache.fineract.organisation.monetary.domain.Money;
 import org.apache.fineract.portfolio.loanaccount.data.DisbursementData;
 import org.apache.fineract.portfolio.loanaccount.data.HolidayDetailDTO;
-import org.apache.fineract.portfolio.loanaccount.data.LoanTermVariationsData;
 import org.apache.fineract.portfolio.loanaccount.data.OutstandingAmountsDTO;
 import org.apache.fineract.portfolio.loanaccount.domain.Loan;
 import org.apache.fineract.portfolio.loanaccount.domain.LoanCharge;
@@ -106,11 +105,8 @@ public class ProgressiveLoanScheduleGenerator implements LoanScheduleGenerator {
         // generate list of proposed schedule due dates
         final List<LoanScheduleModelRepaymentPeriod> expectedRepaymentPeriods = scheduledDateGenerator.generateRepaymentPeriods(mc,
                 periodStartDate, loanApplicationTerms, holidayDetailDTO);
-        List<LoanTermVariationsData> loanTermVariations = loanApplicationTerms.getLoanTermVariations() != null
-                ? loanApplicationTerms.getLoanTermVariations().getExceptionData()
-                : null;
         final ProgressiveLoanInterestScheduleModel interestScheduleModel = emiCalculator.generatePeriodInterestScheduleModel(
-                expectedRepaymentPeriods, loanApplicationTerms.toLoanProductRelatedDetailMinimumData(), loanTermVariations,
+                expectedRepaymentPeriods, loanApplicationTerms.toLoanConfigurationDetails(),
                 loanApplicationTerms.getInstallmentAmountInMultiplesOf(), mc);
         final List<LoanScheduleModelPeriod> periods = new ArrayList<>(expectedRepaymentPeriods.size());
 
@@ -126,19 +122,20 @@ public class ProgressiveLoanScheduleGenerator implements LoanScheduleGenerator {
                     chargesDueAtTimeOfDisbursement, false, mc);
             repaymentPeriod.setPeriodNumber(scheduleParams.getInstalmentNumber());
 
-            emiCalculator.findRepaymentPeriod(interestScheduleModel, repaymentPeriod.getDueDate()).ifPresent(interestRepaymentPeriod -> {
-                final Money principalDue = interestRepaymentPeriod.getDuePrincipal();
-                final Money interestDue = interestRepaymentPeriod.getDueInterest();
+            emiCalculator.findRepaymentPeriod(interestScheduleModel, repaymentPeriod.getFromDate(), repaymentPeriod.getDueDate())
+                    .ifPresent(interestRepaymentPeriod -> {
+                        final Money principalDue = interestRepaymentPeriod.getDuePrincipal();
+                        final Money interestDue = interestRepaymentPeriod.getDueInterest();
 
-                repaymentPeriod.addPrincipalAmount(principalDue);
-                repaymentPeriod.addInterestAmount(interestDue);
-                repaymentPeriod.setOutstandingLoanBalance(interestRepaymentPeriod.getOutstandingLoanBalance());
+                        repaymentPeriod.addPrincipalAmount(principalDue);
+                        repaymentPeriod.addInterestAmount(interestDue);
+                        repaymentPeriod.setOutstandingLoanBalance(interestRepaymentPeriod.getOutstandingLoanBalance());
 
-                scheduleParams.addTotalCumulativePrincipal(principalDue);
-                scheduleParams.addTotalCumulativeInterest(interestDue);
-                // add everything
-                scheduleParams.addTotalRepaymentExpected(principalDue.plus(interestDue, mc));
-            });
+                        scheduleParams.addTotalCumulativePrincipal(principalDue);
+                        scheduleParams.addTotalCumulativeInterest(interestDue);
+                        // add everything
+                        scheduleParams.addTotalRepaymentExpected(principalDue.plus(interestDue, mc));
+                    });
 
             applyChargesForCurrentPeriod(repaymentPeriod, loanCharges, scheduleParams, currency, mc);
             periods.add(repaymentPeriod);
@@ -202,14 +199,22 @@ public class ProgressiveLoanScheduleGenerator implements LoanScheduleGenerator {
 
         Optional<ProgressiveLoanInterestScheduleModel> savedModel = interestScheduleModelRepositoryWrapper.getSavedModel(loan,
                 transactionDate);
-        ProgressiveLoanInterestScheduleModel model = savedModel
-                .orElseGet(() -> processor.calculateInterestScheduleModel(loan.getId(), transactionDate));
+        ProgressiveLoanInterestScheduleModel model = savedModel.orElseThrow();
         OutstandingDetails outstandingAmounts = emiCalculator.getOutstandingAmountsTillDate(model, transactionDate);
         // TODO: We should add all the past due outstanding amounts as well
+
         OutstandingAmountsDTO result = new OutstandingAmountsDTO(currency) //
                 .principal(outstandingAmounts.getOutstandingPrincipal()) //
                 .interest(outstandingAmounts.getOutstandingInterest());//
 
+        if (loan.isProgressiveSchedule()) {
+            final LoanRepaymentScheduleInstallment downPaymentInstallment = loan.getRepaymentScheduleInstallments(i -> i.isDownPayment())
+                    .stream().findFirst().orElse(null);
+            if (downPaymentInstallment != null) {
+                result.principal(downPaymentInstallment.getPrincipalOutstanding(loan.getCurrency())
+                        .add(outstandingAmounts.getOutstandingPrincipal()));
+            }
+        }
         // We need to deduct any paid amount if there is no interest recalculation
         if (!loan.isInterestRecalculationEnabled()) {
             BigDecimal paidInterest = installments.stream().map(LoanRepaymentScheduleInstallment::getInterestPaid).reduce(BigDecimal.ZERO,
@@ -245,9 +250,8 @@ public class ProgressiveLoanScheduleGenerator implements LoanScheduleGenerator {
             return Money.zero(loan.getCurrency());
         }
         Optional<ProgressiveLoanInterestScheduleModel> savedModel = interestScheduleModelRepositoryWrapper.getSavedModel(loan, targetDate);
-        ProgressiveLoanInterestScheduleModel model = savedModel
-                .orElseGet(() -> processor.calculateInterestScheduleModel(loan.getId(), targetDate));
-        return emiCalculator.getPeriodInterestTillDate(model, installment.getDueDate(), targetDate, false);
+        ProgressiveLoanInterestScheduleModel model = savedModel.orElseThrow();
+        return emiCalculator.getPeriodInterestTillDate(model, installment.getFromDate(), installment.getDueDate(), targetDate, false);
     }
 
     // Private, internal methods
@@ -438,7 +442,8 @@ public class ProgressiveLoanScheduleGenerator implements LoanScheduleGenerator {
             } else {
                 amount = amount.add(principalInterestForThisPeriod.principal().getAmount());
             }
-            BigDecimal loanChargeAmt = amount.multiply(loanCharge.getPercentage()).divide(BigDecimal.valueOf(100), mc);
+            Money loanChargeAmt = Money.of(cumulative.getCurrency(),
+                    amount.multiply(loanCharge.getPercentage()).divide(BigDecimal.valueOf(100), mc));
             cumulative = cumulative.plus(loanChargeAmt);
         } else {
             cumulative = cumulative.plus(loanCharge.amountOrPercentage());
@@ -456,7 +461,8 @@ public class ProgressiveLoanScheduleGenerator implements LoanScheduleGenerator {
         } else {
             amount = amount.add(principalDisbursed.getAmount());
         }
-        BigDecimal loanChargeAmt = amount.multiply(loanCharge.getPercentage()).divide(BigDecimal.valueOf(100), mc);
+        Money loanChargeAmt = Money.of(cumulative.getCurrency(),
+                amount.multiply(loanCharge.getPercentage()).divide(BigDecimal.valueOf(100), mc));
         cumulative = cumulative.plus(loanChargeAmt);
         return cumulative;
     }
