@@ -27,6 +27,8 @@ import io.swagger.v3.oas.annotations.parameters.RequestBody;
 import io.swagger.v3.oas.annotations.responses.ApiResponse;
 import io.swagger.v3.oas.annotations.responses.ApiResponses;
 import io.swagger.v3.oas.annotations.tags.Tag;
+import jakarta.validation.Valid;
+import jakarta.ws.rs.BeanParam;
 import jakarta.ws.rs.Consumes;
 import jakarta.ws.rs.GET;
 import jakarta.ws.rs.POST;
@@ -63,14 +65,19 @@ import org.apache.fineract.infrastructure.core.service.CommandParameterUtil;
 import org.apache.fineract.infrastructure.core.service.DateUtils;
 import org.apache.fineract.infrastructure.core.service.ExternalIdFactory;
 import org.apache.fineract.infrastructure.security.service.PlatformSecurityContext;
+import org.apache.fineract.portfolio.loanaccount.api.request.ReAgePreviewRequest;
+import org.apache.fineract.portfolio.loanaccount.api.request.ReAmortizationPreviewRequest;
 import org.apache.fineract.portfolio.loanaccount.data.LoanRepaymentScheduleInstallmentData;
 import org.apache.fineract.portfolio.loanaccount.data.LoanTransactionData;
 import org.apache.fineract.portfolio.loanaccount.domain.LoanTransactionType;
 import org.apache.fineract.portfolio.loanaccount.exception.InvalidLoanTransactionTypeException;
 import org.apache.fineract.portfolio.loanaccount.exception.LoanNotFoundException;
 import org.apache.fineract.portfolio.loanaccount.exception.LoanTransactionNotFoundException;
+import org.apache.fineract.portfolio.loanaccount.loanschedule.data.LoanScheduleData;
 import org.apache.fineract.portfolio.loanaccount.service.LoanChargePaidByReadService;
 import org.apache.fineract.portfolio.loanaccount.service.LoanReadPlatformService;
+import org.apache.fineract.portfolio.loanaccount.service.reaging.LoanReAgingService;
+import org.apache.fineract.portfolio.loanaccount.service.reamortization.LoanReAmortizationService;
 import org.apache.fineract.portfolio.paymenttype.data.PaymentTypeData;
 import org.apache.fineract.portfolio.paymenttype.service.PaymentTypeReadPlatformService;
 import org.springframework.data.domain.Page;
@@ -93,7 +100,8 @@ public class LoanTransactionsApiResource {
     public static final String CAPITALIZED_INCOME = "capitalizedIncome";
     public static final String INTEREST_REFUND_COMMAND_VALUE = "interest-refund";
     private final Set<String> responseDataParameters = new HashSet<>(Arrays.asList("id", "type", "date", "currency", "amount", "externalId",
-            LoanApiConstants.REVERSAL_EXTERNAL_ID_PARAMNAME, LoanApiConstants.REVERSED_ON_DATE_PARAMNAME, "classification"));
+            LoanApiConstants.REVERSAL_EXTERNAL_ID_PARAMNAME, LoanApiConstants.REVERSED_ON_DATE_PARAMNAME, "classification",
+            "numberOfFutureInstallments", "numberOfPastInstallments", "nextInstallmentDueDate", "calculatedStartDate"));
 
     private static final String RESOURCE_NAME_FOR_PERMISSIONS = "LOAN";
 
@@ -104,6 +112,8 @@ public class LoanTransactionsApiResource {
     private final PortfolioCommandSourceWritePlatformService commandsSourceWritePlatformService;
     private final PaymentTypeReadPlatformService paymentTypeReadPlatformService;
     private final LoanChargePaidByReadService loanChargePaidByReadService;
+    private final LoanReAgingService loanReAgingService;
+    private final LoanReAmortizationService loanReAmortizationService;
 
     @GET
     @Path("{loanId}/transactions/template")
@@ -697,6 +707,10 @@ public class LoanTransactionsApiResource {
                     LoanTransactionType.BUY_DOWN_FEE_ADJUSTMENT, transactionId);
         } else if (CommandParameterUtil.is(commandParam, INTEREST_REFUND_COMMAND_VALUE)) {
             transactionData = this.loanReadPlatformService.retrieveManualInterestRefundTemplate(resolvedLoanId, transactionId);
+        } else if (CommandParameterUtil.is(commandParam, LoanApiConstants.REAGE_COMMAND)) {
+            transactionData = this.loanReadPlatformService.retrieveLoanReAgeTemplate(resolvedLoanId);
+        } else if (CommandParameterUtil.is(commandParam, LoanApiConstants.REAMORTIZATION_COMMAND)) {
+            transactionData = this.loanReadPlatformService.retrieveLoanReAmortizationTemplate(resolvedLoanId);
         } else {
             throw new UnrecognizedQueryParamException("command", commandParam);
         }
@@ -773,4 +787,48 @@ public class LoanTransactionsApiResource {
             throw new IllegalArgumentException("loanId and loanExternalId cannot be both null");
         }
     }
+
+    @GET
+    @Path("{loanId}/transactions/reage-preview")
+    @Produces({ MediaType.APPLICATION_JSON })
+    @Operation(summary = "Preview Re-Age Schedule", description = "Generates a preview of the re-aged loan schedule based on the provided parameters without creating any transactions or modifying the loan.")
+    public LoanScheduleData previewReAgeSchedule(@PathParam("loanId") @Parameter(description = "loanId", required = true) final Long loanId,
+            @Valid @BeanParam final ReAgePreviewRequest reAgePreviewRequest) {
+        this.context.authenticatedUser().validateHasReadPermission(RESOURCE_NAME_FOR_PERMISSIONS);
+        return loanReAgingService.previewReAge(loanId, null, reAgePreviewRequest);
+    }
+
+    @GET
+    @Path("external-id/{loanExternalId}/transactions/reage-preview")
+    @Produces({ MediaType.APPLICATION_JSON })
+    @Operation(summary = "Preview Re-Age Schedule", description = "Generates a preview of the re-aged loan schedule based on the provided parameters without creating any transactions or modifying the loan.")
+    public LoanScheduleData previewReAgeSchedule(
+            @PathParam("loanExternalId") @Parameter(description = "loanExternalId", required = true) final String loanExternalId,
+            @Valid @BeanParam final ReAgePreviewRequest reAgePreviewRequest) {
+        this.context.authenticatedUser().validateHasReadPermission(RESOURCE_NAME_FOR_PERMISSIONS);
+        return loanReAgingService.previewReAge(null, loanExternalId, reAgePreviewRequest);
+    }
+
+    @GET
+    @Path("{loanId}/transactions/reamortization-preview")
+    @Produces({ MediaType.APPLICATION_JSON })
+    @Operation(summary = "Preview Re-Amortized Schedule", description = "Generates a preview of the re-amortized loan schedule based on the provided parameters without creating any transactions or modifying the loan.")
+    public LoanScheduleData previewReAmortizationSchedule(
+            @PathParam("loanId") @Parameter(description = "loanId", required = true) final Long loanId,
+            @Valid @BeanParam final ReAmortizationPreviewRequest reAmortizationPreviewRequest) {
+        this.context.authenticatedUser().validateHasReadPermission(RESOURCE_NAME_FOR_PERMISSIONS);
+        return loanReAmortizationService.previewReAmortization(loanId, null, reAmortizationPreviewRequest);
+    }
+
+    @GET
+    @Path("external-id/{loanExternalId}/transactions/reamortization-preview")
+    @Produces({ MediaType.APPLICATION_JSON })
+    @Operation(summary = "Preview Re-amortized Schedule", description = "Generates a preview of the re-amortized loan schedule based on the provided parameters without creating any transactions or modifying the loan.")
+    public LoanScheduleData previewReAmortizationSchedule(
+            @PathParam("loanExternalId") @Parameter(description = "loanExternalId", required = true) final String loanExternalId,
+            @Valid @BeanParam final ReAmortizationPreviewRequest reAmortizationPreviewRequest) {
+        this.context.authenticatedUser().validateHasReadPermission(RESOURCE_NAME_FOR_PERMISSIONS);
+        return loanReAmortizationService.previewReAmortization(null, loanExternalId, reAmortizationPreviewRequest);
+    }
+
 }
