@@ -42,7 +42,10 @@ import org.apache.fineract.infrastructure.core.service.ThreadLocalContextUtil;
 import org.apache.fineract.organisation.monetary.domain.MonetaryCurrency;
 import org.apache.fineract.organisation.monetary.domain.Money;
 import org.apache.fineract.organisation.monetary.domain.MoneyHelper;
+import org.apache.fineract.portfolio.delinquency.domain.DelinquencyAction;
+import org.apache.fineract.portfolio.delinquency.domain.LoanDelinquencyAction;
 import org.apache.fineract.portfolio.delinquency.helper.DelinquencyEffectivePauseHelper;
+import org.apache.fineract.portfolio.delinquency.helper.DelinquencyEffectivePauseHelperImpl;
 import org.apache.fineract.portfolio.delinquency.service.LoanDelinquencyDomainServiceImpl;
 import org.apache.fineract.portfolio.delinquency.validator.LoanDelinquencyActionData;
 import org.apache.fineract.portfolio.loanaccount.data.CollectionData;
@@ -159,7 +162,8 @@ public class LoanDelinquencyDomainServiceTest {
         when(loan.getLastLoanRepaymentScheduleInstallment()).thenReturn(repaymentScheduleInstallments.get(0));
         when(loan.getCurrency()).thenReturn(currency);
         when(loan.getStatus()).thenReturn(LoanStatus.ACTIVE);
-        when(delinquencyEffectivePauseHelper.getPausedDaysBeforeDate(effectiveDelinquencyList, businessDate)).thenReturn(0L);
+        when(delinquencyEffectivePauseHelper.getPausedDaysWithinRange(Mockito.eq(effectiveDelinquencyList), Mockito.any(),
+                Mockito.eq(businessDate))).thenReturn(0L);
 
         CollectionData collectionData = underTest.getOverdueCollectionData(loan, effectiveDelinquencyList);
 
@@ -229,7 +233,8 @@ public class LoanDelinquencyDomainServiceTest {
         when(loan.getCurrency()).thenReturn(currency);
         when(loan.isEnableInstallmentLevelDelinquency()).thenReturn(true);
         when(loan.getStatus()).thenReturn(LoanStatus.ACTIVE);
-        when(delinquencyEffectivePauseHelper.getPausedDaysBeforeDate(effectiveDelinquencyList, businessDate)).thenReturn(0L);
+        when(delinquencyEffectivePauseHelper.getPausedDaysWithinRange(Mockito.eq(effectiveDelinquencyList), Mockito.any(),
+                Mockito.eq(businessDate))).thenReturn(0L);
 
         LoanDelinquencyData collectionData = underTest.getLoanDelinquencyData(loan, effectiveDelinquencyList);
 
@@ -281,7 +286,8 @@ public class LoanDelinquencyDomainServiceTest {
         when(loan.getStatus()).thenReturn(LoanStatus.ACTIVE);
         when(loanTransactionReadService.fetchLoanTransactionsByType(loan.getId(), null, LoanTransactionType.CHARGEBACK))
                 .thenReturn(Arrays.asList(loanTransaction));
-        when(delinquencyEffectivePauseHelper.getPausedDaysBeforeDate(effectiveDelinquencyList, businessDate)).thenReturn(0L);
+        when(delinquencyEffectivePauseHelper.getPausedDaysWithinRange(Mockito.eq(effectiveDelinquencyList), Mockito.any(),
+                Mockito.eq(businessDate))).thenReturn(0L);
 
         LoanDelinquencyData collectionData = underTest.getLoanDelinquencyData(loan, effectiveDelinquencyList);
 
@@ -305,4 +311,108 @@ public class LoanDelinquencyDomainServiceTest {
 
     }
 
+    @Test
+    public void givenPausePeriodThenInstallmentDelinquentDaysOnlyIncludeOverlap() {
+        LocalDate overriddenBusinessDate = LocalDate.of(2022, 3, 2);
+        ThreadLocalContextUtil.setBusinessDates(new HashMap<>(Map.of(BusinessDateType.BUSINESS_DATE, overriddenBusinessDate)));
+
+        LoanRepaymentScheduleInstallment installmentOne = new LoanRepaymentScheduleInstallment(loan, 1, LocalDate.of(2021, 12, 1),
+                LocalDate.of(2022, 1, 16), principal, zeroAmount, zeroAmount, zeroAmount, false, new HashSet<>(), zeroAmount);
+        installmentOne.setId(1L);
+        LoanRepaymentScheduleInstallment installmentTwo = new LoanRepaymentScheduleInstallment(loan, 2, LocalDate.of(2022, 1, 16),
+                LocalDate.of(2022, 1, 31), principal, zeroAmount, zeroAmount, zeroAmount, false, new HashSet<>(), zeroAmount);
+        installmentTwo.setId(2L);
+        LoanRepaymentScheduleInstallment installmentThree = new LoanRepaymentScheduleInstallment(loan, 3, LocalDate.of(2022, 1, 31),
+                LocalDate.of(2022, 2, 15), principal, zeroAmount, zeroAmount, zeroAmount, false, new HashSet<>(), zeroAmount);
+        installmentThree.setId(3L);
+
+        List<LoanRepaymentScheduleInstallment> repaymentScheduleInstallments = Arrays.asList(installmentOne, installmentTwo,
+                installmentThree);
+
+        when(loanProductRelatedDetail.getGraceOnArrearsAgeing()).thenReturn(0);
+        when(loan.getLoanProductRelatedDetail()).thenReturn(loanProductRelatedDetail);
+        when(loan.getRepaymentScheduleInstallments()).thenReturn(repaymentScheduleInstallments);
+        when(loanTransactionReadService.fetchLoanTransactionsByType(loan.getId(), null, LoanTransactionType.CHARGEBACK))
+                .thenReturn(Collections.emptyList());
+        when(loan.getLastLoanRepaymentScheduleInstallment()).thenReturn(installmentThree);
+        when(loan.getCurrency()).thenReturn(currency);
+        when(loan.isEnableInstallmentLevelDelinquency()).thenReturn(true);
+        when(loan.getStatus()).thenReturn(LoanStatus.ACTIVE);
+
+        LoanDelinquencyAction pauseAction = new LoanDelinquencyAction(null, DelinquencyAction.PAUSE, LocalDate.of(2022, 1, 20),
+                LocalDate.of(2022, 1, 30));
+        pauseAction.setId(1L);
+        LoanDelinquencyActionData pauseData = new LoanDelinquencyActionData(pauseAction);
+        List<LoanDelinquencyActionData> effectiveDelinquencyList = List.of(pauseData);
+
+        LoanDelinquencyDomainServiceImpl service = new LoanDelinquencyDomainServiceImpl(new DelinquencyEffectivePauseHelperImpl(),
+                loanTransactionReadService);
+
+        LoanDelinquencyData collectionData = service.getLoanDelinquencyData(loan, effectiveDelinquencyList);
+
+        CollectionData loanCollectionData = collectionData.getLoanCollectionData();
+        assertEquals(35L, loanCollectionData.getDelinquentDays());
+        assertEquals(LocalDate.of(2022, 1, 16), loanCollectionData.getDelinquentDate());
+
+        Map<Long, CollectionData> installments = collectionData.getLoanInstallmentsCollectionData();
+        assertNotNull(installments);
+        assertEquals(3, installments.size());
+        assertEquals(35L, installments.get(1L).getDelinquentDays());
+        assertEquals(30L, installments.get(2L).getDelinquentDays());
+        assertEquals(15L, installments.get(3L).getDelinquentDays());
+    }
+
+    @Test
+    public void givenMultipleInstallmentsAndPauseThenDelinquencyDaysDistributePerInstallment() {
+        LocalDate businessDate = LocalDate.of(2022, 2, 5);
+        ThreadLocalContextUtil.setBusinessDates(new HashMap<>(Map.of(BusinessDateType.BUSINESS_DATE, businessDate)));
+
+        Loan localLoan = Mockito.mock(Loan.class);
+        LoanProductRelatedDetail localDetails = Mockito.mock(LoanProductRelatedDetail.class);
+        MonetaryCurrency currency = new MonetaryCurrency("USD", 2, null);
+
+        LoanRepaymentScheduleInstallment installmentOne = new LoanRepaymentScheduleInstallment(localLoan, 1, LocalDate.of(2021, 12, 26),
+                LocalDate.of(2022, 1, 10), principal, zeroAmount, zeroAmount, zeroAmount, false, new HashSet<>(), zeroAmount);
+        installmentOne.setId(1L);
+        LoanRepaymentScheduleInstallment installmentTwo = new LoanRepaymentScheduleInstallment(localLoan, 2, LocalDate.of(2022, 1, 10),
+                LocalDate.of(2022, 1, 20), principal, zeroAmount, zeroAmount, zeroAmount, false, new HashSet<>(), zeroAmount);
+        installmentTwo.setId(2L);
+        LoanRepaymentScheduleInstallment installmentThree = new LoanRepaymentScheduleInstallment(localLoan, 3, LocalDate.of(2022, 1, 20),
+                LocalDate.of(2022, 1, 30), principal, zeroAmount, zeroAmount, zeroAmount, false, new HashSet<>(), zeroAmount);
+        installmentThree.setId(3L);
+
+        List<LoanRepaymentScheduleInstallment> installments = Arrays.asList(installmentOne, installmentTwo, installmentThree);
+
+        when(localLoan.getId()).thenReturn(42L);
+        when(localLoan.getLoanProductRelatedDetail()).thenReturn(localDetails);
+        when(localDetails.getGraceOnArrearsAgeing()).thenReturn(0);
+        when(localLoan.getRepaymentScheduleInstallments()).thenReturn(installments);
+        when(localLoan.getLastLoanRepaymentScheduleInstallment()).thenReturn(installmentThree);
+        when(localLoan.getCurrency()).thenReturn(currency);
+        when(localLoan.isEnableInstallmentLevelDelinquency()).thenReturn(true);
+        when(localLoan.getStatus()).thenReturn(LoanStatus.ACTIVE);
+
+        when(loanTransactionReadService.fetchLoanTransactionsByType(localLoan.getId(), null, LoanTransactionType.CHARGEBACK))
+                .thenReturn(Collections.emptyList());
+
+        LoanDelinquencyAction pauseAction = new LoanDelinquencyAction(localLoan, DelinquencyAction.PAUSE, LocalDate.of(2022, 1, 15),
+                LocalDate.of(2022, 1, 25));
+        List<LoanDelinquencyActionData> effectiveDelinquencyList = new DelinquencyEffectivePauseHelperImpl()
+                .calculateEffectiveDelinquencyList(List.of(pauseAction));
+
+        LoanDelinquencyDomainServiceImpl service = new LoanDelinquencyDomainServiceImpl(new DelinquencyEffectivePauseHelperImpl(),
+                loanTransactionReadService);
+
+        LoanDelinquencyData delinquencyData = service.getLoanDelinquencyData(localLoan, effectiveDelinquencyList);
+
+        CollectionData loanCollectionData = delinquencyData.getLoanCollectionData();
+        assertEquals(16L, loanCollectionData.getDelinquentDays());
+        assertEquals(LocalDate.of(2022, 1, 10), loanCollectionData.getDelinquentDate());
+
+        Map<Long, CollectionData> installmentData = delinquencyData.getLoanInstallmentsCollectionData();
+        assertEquals(3, installmentData.size());
+        assertEquals(16L, installmentData.get(1L).getDelinquentDays());
+        assertEquals(11L, installmentData.get(2L).getDelinquentDays());
+        assertEquals(6L, installmentData.get(3L).getDelinquentDays());
+    }
 }
