@@ -88,6 +88,7 @@ public class LoanApplicationTestBuilder {
     private boolean enableDownPayment = false;
     private boolean enableAutoRepaymentForDownPayment = false;
     private String disbursedAmountPercentageDownPayment;
+    private Boolean allowFullTermForTranche = null;
 
     public String build(final String clientID, final String groupID, final String loanProductId, final String savingsID) {
         final HashMap<String, Object> map = new HashMap<>();
@@ -220,6 +221,9 @@ public class LoanApplicationTestBuilder {
         if (disbursedAmountPercentageDownPayment != null) {
             map.put("disbursedAmountPercentageDownPayment", disbursedAmountPercentageDownPayment);
         }
+        if (allowFullTermForTranche != null) {
+            map.put("allowFullTermForTranche", allowFullTermForTranche);
+        }
         LOG.info("Loan Application request : {} ", map);
         return new Gson().toJson(map);
     }
@@ -468,4 +472,9 @@ public class LoanApplicationTestBuilder {
         return this;
     }
 
+    public LoanApplicationTestBuilder withAllowFullTermForTranche(final Boolean allowFullTermForTranche) {
+        this.allowFullTermForTranche = allowFullTermForTranche;
+        return this;
+    }
+
 }
